pub struct SessionRunner { /* private fields */ }Expand description
Coordinator that drives run_agent while persisting the session after
every turn. Implements TurnSink so the loop calls back after each turn.
Implementations
Sourceimpl SessionRunner
impl SessionRunner
Sourcepub fn new(
adapter: Arc<dyn PersistenceAdapter>,
session_id: SessionId,
model: impl Into<String>,
max_turns: usize,
system_message: Option<String>,
) -> Self
pub fn new( adapter: Arc<dyn PersistenceAdapter>, session_id: SessionId, model: impl Into<String>, max_turns: usize, system_message: Option<String>, ) -> Self
Create a runner for a new or empty session.
Sourcepub async fn load(
adapter: Arc<dyn PersistenceAdapter>,
session_id: SessionId,
) -> RuntimeResult<Option<Self>>
pub async fn load( adapter: Arc<dyn PersistenceAdapter>, session_id: SessionId, ) -> RuntimeResult<Option<Self>>
Load a persisted session into a runner, if the adapter has one.
Sourcepub fn messages(&self) -> Vec<AgentMessage>
pub fn messages(&self) -> Vec<AgentMessage>
Snapshot the runner’s current messages.
Sourcepub fn system_message(&self) -> Option<String>
pub fn system_message(&self) -> Option<String>
The system message (instructions) for this session, if any.